package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/ConstantValue.class */
public final class ConstantValue extends Attribute {
    private int constantValueIndex;

    public ConstantValue(ConstantValue c) {
        this(c.getNameIndex(), c.getLength(), c.getConstantValueIndex(), c.getConstantPool());
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public ConstantValue(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
        this(nameIndex, length, input.readUnsignedShort(), constantPool);
    }

    public ConstantValue(int nameIndex, int length, int constantValueIndex, ConstantPool constantPool) {
        super((byte) 1, nameIndex, length, constantPool);
        this.constantValueIndex = constantValueIndex;
    }

    @Override // org.apache.bcel.classfile.Attribute, org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitConstantValue(this);
    }

    @Override // org.apache.bcel.classfile.Attribute
    public Attribute copy(ConstantPool constantPool) {
        ConstantValue c = (ConstantValue) clone();
        c.setConstantPool(constantPool);
        return c;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public void dump(DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.constantValueIndex);
    }

    public int getConstantValueIndex() {
        return this.constantValueIndex;
    }

    public void setConstantValueIndex(int constantValueIndex) {
        this.constantValueIndex = constantValueIndex;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public String toString() {
        String buf;
        Constant c = super.getConstantPool().getConstant(this.constantValueIndex);
        switch (c.getTag()) {
            case JavaClass.ZIP /* 3 */:
                buf = String.valueOf(((ConstantInteger) c).getBytes());
                break;
            case 4:
                buf = String.valueOf(((ConstantFloat) c).getBytes());
                break;
            case 5:
                buf = String.valueOf(((ConstantLong) c).getBytes());
                break;
            case 6:
                buf = String.valueOf(((ConstantDouble) c).getBytes());
                break;
            case 7:
            default:
                throw new IllegalStateException("Type of ConstValue invalid: " + c);
            case 8:
                int i = ((ConstantString) c).getStringIndex();
                buf = "\"" + Utility.convertString(super.getConstantPool().getConstantUtf8(i).getBytes()) + "\"";
                break;
        }
        return buf;
    }
}
